@@ -131,6 +131,8 @@ void init_x_and_imlib(void)
 	imlib_context_set_operation(IMLIB_OP_COPY);
 	wmDeleteWindow = XInternAtom(disp, "WM_DELETE_WINDOW", False);
 
+	imlib_set_cache_size(opt.cache_size * 1024 * 1024);
+
 	/* Initialise random numbers */
 	srand(getpid() * time(NULL) % ((unsigned int) -1));
 
@@ -254,6 +256,16 @@ int feh_load_image(Imlib_Image * im, feh_file * file)
 		return(0);
 	}
 
+	/*
+	 * By default, Imlib2 unconditionally loads a cached file without checking
+	 * if it was modified on disk. However, feh (or rather its users) should
+	 * expect image changes to appear at the next reload. So we tell Imlib2 to
+	 * always check the file modification time and only use a cached image if
+	 * the mtime was not changed. The performance penalty is usually negligible.
+	 */
+	imlib_context_set_image(*im);
+	imlib_image_set_changes_on_disk();
+
 #ifdef HAVE_LIBEXIF
 	int orientation = 0;
 	ExifData *exifData = exif_data_new_from_file(file->filename);
@@ -429,7 +441,7 @@ static char *feh_http_load_image(char *url)
 			if (opt.insecure_ssl) {
 				curl_easy_setopt(curl, CURLOPT_SSL_VERIFYPEER, 0);
 				curl_easy_setopt(curl, CURLOPT_SSL_VERIFYHOST, 0);
-			} else {
+			} else if (getenv("CURL_CA_BUNDLE") != NULL) {
 				// Allow the user to specify custom CA certificates.
 				curl_easy_setopt(curl, CURLOPT_CAINFO,
 						getenv("CURL_CA_BUNDLE"));
@@ -467,7 +479,7 @@ static char *feh_http_load_image(char *url)
 char *feh_http_load_image(char *url)
 {
 	weprintf(
-		"Cannot load image %s\n Please recompile with libcurl support",
+		"Cannot load image %s\nPlease recompile feh with libcurl support",
 		url
 	);
 	return NULL;
